@@ -1,43 +1,43 @@
-\echo -- q1
+/* -- q1 */
 SELECT * FROM pgr_edwardMoore(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3
 );
-\echo -- q2
+/* -- q2 */
 SELECT * FROM pgr_edwardMoore(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3,
     FALSE
 );
-\echo -- q3
+/* -- q3 */
 SELECT * FROM pgr_edwardMoore(
     'SELECT id, source, target, cost FROM edge_table',
     2, ARRAY[3,5],
     FALSE
 );
-\echo -- q4
+/* -- q4 */
 SELECT * FROM pgr_edwardMoore(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[2,11], 5
 );
-\echo -- q5
+/* -- q5 */
 SELECT * FROM pgr_edwardMoore(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[2,11], ARRAY[3,5],
     FALSE
 );
-\echo -- q6
+/* -- q6 */
 SELECT * FROM pgr_edwardMoore(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     'SELECT * FROM ( VALUES (2, 3), (11, 5) ) AS t(source, target)',
     FALSE
 );
-\echo -- q7
+/* -- q7 */
 
 -- Examples for :ref:`fig1-direct-Cost-Reverse`
 -------------------------------------------------------------------------------
 
-\echo -- q8
+/* -- q8 */
 SELECT * FROM pgr_edwardMoore(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3
@@ -66,14 +66,14 @@ SELECT * FROM pgr_edwardMoore(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     ARRAY[2, 11], ARRAY[3,5]
 );
-\echo -- q9
+/* -- q9 */
 
 
 -- Examples for :ref:`fig2-undirect-Cost-Reverse`
 -------------------------------------------------------------------------------
 
 
-\echo -- q10
+/* -- q10 */
 SELECT * FROM pgr_edwardMoore(
     'SELECT id, source, target, cost, reverse_cost FROM edge_table',
     2, 3,
@@ -109,14 +109,14 @@ SELECT * FROM pgr_edwardMoore(
     ARRAY[2, 11], ARRAY[3,5],
     FALSE
 );
-\echo -- q11
+/* -- q11 */
 
 
 -- Examples for :ref:`fig3-direct-Cost`
 -------------------------------------------------------------------------------
 
 
-\echo -- q12
+/* -- q12 */
 SELECT * FROM pgr_edwardMoore(
     'SELECT id, source, target, cost FROM edge_table',
     2, 3
@@ -145,13 +145,13 @@ SELECT * FROM pgr_edwardMoore(
     'SELECT id, source, target, cost FROM edge_table',
     ARRAY[2, 11], ARRAY[3,5]
 );
-\echo -- q13
+/* -- q13 */
 
 
 -- Examples for :ref:`fig4-undirect-Cost`
 -------------------------------------------------------------------------------
 
-\echo -- q14
+/* -- q14 */
 SELECT * FROM pgr_edwardMoore(
     'SELECT id, source, target, cost FROM edge_table',
     2, 3,
@@ -187,4 +187,4 @@ SELECT * FROM pgr_edwardMoore(
     ARRAY[2, 11], ARRAY[3,5],
     FALSE
 );
-\echo -- q15
+/* -- q15 */
