@@ -49,15 +49,15 @@ namespace algorithms {
 /**
  * works for undirected graph
  **/
-std::vector<pgr_components_rt>
+std::vector<II_t_rt>
 pgr_connectedComponents(pgrouting::UndirectedGraph &graph);
 
 //! Strongly Connected Components Vertex Version
-std::vector<pgr_components_rt>
+std::vector<II_t_rt>
 strongComponents(pgrouting::DirectedGraph &graph);
 
 //! Biconnected Components (for undirected)
-std::vector<pgr_components_rt>
+std::vector<II_t_rt>
 biconnectedComponents(pgrouting::UndirectedGraph &graph);
 
 //! Articulation Points
