@@ -1,4 +1,4 @@
-\i setup.sql
+BEGIN;
 
 UPDATE edge_table SET cost = sign(cost), reverse_cost = sign(reverse_cost);
 SELECT plan(3);
@@ -9,30 +9,29 @@ id integer,
 x float8,
 y float8);
 
-copy nodes(id,x,y) FROM stdin WITH DELIMITER '|';
-156|351885.927|739332.781
-156|351893|739579
-156|352004.408|739375.19
-126|352004.408|739375.19
-125|352473|739498
-126|352473|739498
-150|352543|741610
-161|352893.205|740082.415
-160|352893.205|740082.415
-280|352893.205|740082.415
-146|352984.15|739941.023
-160|352984.15|739941.023
-125|352984.15|739941.023
-150|353370|740397
-151|353370|740397
-146|353370|740397
-151|353400|740376
-154|353400.927|741347.893
-251|353486.777|740517.047
-154|353486.777|740517.047
-151|353486.777|740517.047
-251|353752.373|740768.525
-\.
+INSERT INTO nodes(id,x,y) VALUES
+(156, 351885.927, 739332.781),
+(156, 351893, 739579),
+(156, 352004.408, 739375.19),
+(126, 352004.408, 739375.19),
+(125, 352473, 739498),
+(126, 352473, 739498),
+(150, 352543, 741610),
+(161, 352893.205, 740082.415),
+(160, 352893.205, 740082.415),
+(280, 352893.205, 740082.415),
+(146, 352984.15, 739941.023),
+(160, 352984.15, 739941.023),
+(125, 352984.15, 739941.023),
+(150, 353370, 740397),
+(151, 353370, 740397),
+(146, 353370, 740397),
+(151, 353400, 740376),
+(154, 353400.927, 741347.893),
+(251, 353486.777, 740517.047),
+(154, 353486.777, 740517.047),
+(151, 353486.777, 740517.047),
+(251, 353752.373, 740768.525);
 
 
 PREPARE q1 AS
