@@ -35,13 +35,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include "c_common/edges_input.h"
 #include "c_types/geom_text_rt.h"
 
-#if Boost_VERSION_MACRO >= 105400
 #include "drivers/alpha_shape/alphaShape_driver.h"
-#endif
 
 PGDLLEXPORT Datum _pgr_alphashape(PG_FUNCTION_ARGS);
 
-#if Boost_VERSION_MACRO >= 105400
 static void process(
         char* edges_sql,
         double alpha,
@@ -50,7 +47,7 @@ static void process(
         size_t *result_count) {
     pgr_SPI_connect();
 
-    Pgr_edge_xy_t *edgesArr = NULL;
+    Edge_xy_t *edgesArr = NULL;
     size_t edgesSize = 0;
 
     pgr_get_edges_xy(edges_sql, &edgesArr, &edgesSize);
@@ -102,7 +99,6 @@ static void process(
     if (edgesArr) pfree(edgesArr);
     pgr_SPI_finish();
 }
-#endif
 
 PG_FUNCTION_INFO_V1(_pgr_alphashape);
 
@@ -123,24 +119,15 @@ Datum _pgr_alphashape(PG_FUNCTION_ARGS) {
 
         /******************************************************************/
 
-#if Boost_VERSION_MACRO >= 105400
         process(
                 text_to_cstring(PG_GETARG_TEXT_P(0)),
                 PG_GETARG_FLOAT8(1),
                 &result_tuples,
                 &result_count);
-#else
-        elog(ERROR, "Please compile with Boost >= 1.54 to have pgr_alphaShape.");
-#endif
 
         /******************************************************************/
 
-#if PGSQL_VERSION > 95
         funcctx->max_calls = result_count;
-#else
-        funcctx->max_calls = (uint32_t)result_count;
-#endif
-
         funcctx->user_fctx = result_tuples;
         if (get_call_result_type(fcinfo, NULL, &tuple_desc) != TYPEFUNC_COMPOSITE)
             ereport(ERROR,
